import {v4 as uuidV4} from 'uuid';

import {ref} from "vue";
import DHApp from "../DHApp";
import {arrayBufferToBase64, concatenatePCM, playPCM} from "../utils/audioUtils";

export default function useAudioRender() {
    const commandId = ref(uuidV4());

    // 单独抽取一个函数用于获取 PCM 数据
    const fetchPCM = async (url: RequestInfo | URL) => {
        const response = await fetch(url);
        if (!response.ok) {
            throw new Error('Network response was not ok');
        }
        return response.arrayBuffer();
    };

    const sendAudio = (arrayBuffer: ArrayBuffer) => {
        const base64String = arrayBufferToBase64(arrayBuffer); // pcm转base64
        DHApp.sendAudioData({
            action: 'AUDIO_RENDER',
            body: base64String,
            requestId: commandId.value
        })
    };

    const playAudio = async () => {
        // 获取本地的 PCM 文件数据
        try {
            const arrayBuffer1 = await fetchPCM('test.pcm');
            // 播放音频并发送数据
            // playPCM(arrayBuffer1, 16, 1); // 前端test
            sendAudio(arrayBuffer1);
        } catch (error) {
            console.error('There has been a problem with your fetch operation:', error);
        }
    };
    const playMultiAudio = async () => {
        try {
            // 使用 Promise.all 并行获取两个音频片段
            const [arrayBuffer1, arrayBuffer2] = await Promise.all([
                fetchPCM('test.pcm'),
                fetchPCM('test.pcm')
            ]);
            // 拼接音频数据
            const concatenatedBuffer = concatenatePCM(arrayBuffer1, arrayBuffer2, 16);
            // 播放音频并发送数据
            // playPCM(concatenatedBuffer, 16, 1); // 前端test
            sendAudio(concatenatedBuffer);
        } catch (error) {
            console.error('There has been a problem with your fetch operation:', error);
        }
    };
    return {
        playAudio,
        playMultiAudio
    };
}
